==> walkers-fabric-1.18.2-5.3.3-sources.jar: tocraft/walkers/ability/impl/specific/LlamaAbility.java <==
package tocraft.walkers.ability.impl.specific;

import net.minecraft.class_1299;
import net.minecraft.class_1308;
import net.minecraft.class_1657;
import net.minecraft.class_1673;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_243;
import net.minecraft.class_3417;
import tocraft.walkers.ability.ShapeAbility;

public class LlamaAbility<T extends class_1308> extends ShapeAbility<T> {
    @Override
    public void onUse(class_1657 player, T shape, class_1937 world) {
        class_1673 spit = new class_1673(class_1299.field_6124, world);
        spit.method_7432(player);
        class_243 rotation = player.method_5720();
        spit.method_7485(rotation.field_1352, rotation.field_1351, rotation.field_1350, 1.5F, 10.0F);
        //#if MC>1182
        spit.syncPacketPositionCodec(player.method_23317(), player.method_23320(), player.method_23321());
        //#else
        //$$ spit.lerpMotion(player.getX(), player.getEyeY(), player.getZ());
        //#endif
        spit.method_30634(player.method_23317(), player.method_23320(), player.method_23321());

        // Play SFX
        world.method_8465(null, player.method_23317(), player.method_23318(), player.method_23321(), class_3417.field_14789, player.method_5634(), 1.0F, 1.0F + (world.field_9229.nextFloat() - world.field_9229.nextFloat()) * 0.2F);

        world.method_8649(spit);
    }

    @Override
    public class_1792 getIcon() {
        return class_1802.field_8719;
    }
}

==> walkers-fabric-1.19.4-5.3-sources.jar: tocraft/walkers/ability/impl/specific/LlamaAbility.java <==
package tocraft.walkers.ability.impl.specific;

import net.minecraft.class_1299;
import net.minecraft.class_1308;
import net.minecraft.class_1657;
import net.minecraft.class_1673;
import net.minecraft.class_1792;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_243;
import net.minecraft.class_3417;
import tocraft.walkers.ability.ShapeAbility;

public class LlamaAbility<T extends class_1308> extends ShapeAbility<T> {
    @Override
    public void onUse(class_1657 player, T shape, class_1937 world) {
        class_1673 spit = new class_1673(class_1299.field_6124, world);
        spit.method_7432(player);
        class_243 rotation = player.method_5720();
        spit.method_7485(rotation.field_1352, rotation.field_1351, rotation.field_1350, 1.5F, 10.0F);
        //#if MC>1182
        spit.method_43391(player.method_23317(), player.method_23320(), player.method_23321());
        //#else
        //$$ spit.lerpMotion(player.getX(), player.getEyeY(), player.getZ());
        //#endif
        spit.method_30634(player.method_23317(), player.method_23320(), player.method_23321());

        // Play SFX
        world.method_43128(null, player.method_23317(), player.method_23318(), player.method_23321(), class_3417.field_14789, player.method_5634(), 1.0F, 1.0F + (world.field_9229.method_43057() - world.field_9229.method_43057()) * 0.2F);

        world.method_8649(spit);
    }

    @Override
    public class_1792 getIcon() {
        return class_1802.field_8719;
    }
}
